Syncing charts

<div id="wrapper"> <div id="chart-line"> <apexchart type="line" height="160" :options="chartOptions" :series="series"></apexchart> </div> <div id="chart-line2"> <apexchart type="line" height="160" :options="chartOptionsLine2" :series="seriesLine2"></apexchart> </div> <div id="chart-area"> <apexchart type="area" height="160" :options="chartOptionsArea" :series="seriesArea"></apexchart> </div> <div class="columns"> <div id="chart-small"> <apexchart type="area" height="160" width="300" :options="chartOptionsSmall" :series="seriesSmall"></apexchart> </div> <div id="chart-small2"> <apexchart type="area" height="160" width="300" :options="chartOptionsSmall2" :series="seriesSmall2"></apexchart> </div> </div> </div>